# /packages/intranet-trans-project-feedback/www/graph-panel.tcl
#
# Copyright (C) 2015 Project Open Business Solutions S.L.
#
# This program is free software. You can redistribute it
# and/or modify it under the terms of the GNU General
# Public License as published by the Free Software Foundation;
# either version 2 of the License, or (at your option)
# any later version. This program is distributed in the
# hope that it will be useful, but WITHOUT ANY WARRANTY;
# without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.

# Profiles represent OpenACS groups used by ]project-open[
# However, for performance reasons we have introduced special
# caching and auxillary functions specific to ]po[.

# @author klaus.hofeditz@project-open.com

# ---------------------------------------------------------------------------
# DEFAULTS & PERMISSIONS 
# ---------------------------------------------------------------------------

# Provided: 
# 	title
# 	start_date
# 	end_date
#	period


set current_url [ns_conn url]
set current_user_id [ad_maybe_redirect_for_registration]
set package_url "/simple-survey"
set report_code_found_p 1
if ![info exists return_url] { set return_url "/intranet-trans-project-feedback/dashboard" }

# Set dynamic width 
set num_days [db_string get_number_days "select '$end_date'::date - '$start_date'::date" -default 0] 

switch $period {
    month {
        set data_points_horiz [expr $num_days / 30]
    }
    quarter {
        set data_points_horiz [expr $num_days / 120]
    }
    year {
        set data_points_horiz [expr $num_days / 365]
    }
    default {
        set data_points_horiz 0 	
    }
}

set data_points_horiz [format "%.2f" [expr {double(round(100*$data_points_horiz))/100}]]

# Determine size based on number od datapoints found 
if { $data_points_horiz < 7 } { set diagram_width 500} else { set diagram_width 1000 }

# Set Report Code 
switch $title {
    "Non Conformity" {
	set store "translationProjectFeedbackNonConformityStore"
	set chart_type "column_chart"
	set diagram_report_code "translation_project_feedback_non_conformity" 
	if {![info exists diagram_height] || "" == $diagram_height } { set diagram_height 350 }
	if {![info exists diagram_font] || "" == $diagram_font} { set diagram_font "10px Helvetica, sans-serif" }
	if {![info exists diagram_theme] || "" == $diagram_theme} { set diagram_theme "Custom" }
	if {![info exists diagram_limit] || "" == $diagram_limit} { set diagram_limit 100 }
	if {![info exists diagram_inset_padding] || "" == $diagram_inset_padding} { set diagram_inset_padding 5 }
	if {![info exists diagram_tooltip_width] || "" == $diagram_tooltip_width} { set diagram_tooltip_width 230 }
	if {![info exists diagram_tooltip_height] || "" == $diagram_tooltip_height} { set diagram_tooltip_height 20 }
	if {![info exists diagram_legend_width] || "" == $diagram_legend_width} { set diagram_legend_width 150 }
	if {![info exists diagram_title] || "" == $diagram_title} { set diagram_title [lang::message::lookup "" intranet-trans-project-feedback.$title $title] }
	set diagram_id "translation_project_feedback_non_conformity"
    }
    "Non Conformity - Proportions" {
	set store "translationProjectFeedbackNonConformityProportionStore"
	set chart_type "pie_chart"
        set diagram_report_code "translation_project_feedback_non_conformity_proportions"
        if {![info exists diagram_limit] || "" == $diagram_limit} { set diagram_limit 100 }

	# if {![info exists diagram_width] || "" == $diagram_width} { set diagram_width 350 }
        # if {![info exists diagram_height] || "" == $diagram_height } { set diagram_height 350 }
	set diagram_width 1000
	set diagram_height 300

	set diagram_id "translation_project_feedback_non_conformity_proportions"
    }
    "Conformity vs Non-Conformity" {
        if {![info exists diagram_font] || "" == $diagram_font} { set diagram_font "10px Helvetica, sans-serif" }
	set store "translationProjectFeedbackNonConformityStore"
	set chart_type "line_chart"
        set diagram_report_code "translation_project_feedback_non_conformity"
	if {![info exists diagram_limit] || "" == $diagram_limit} { set diagram_limit 100 }
        if {![info exists diagram_height] || "" == $diagram_height } { set diagram_height 350 }
	set diagram_id "translation_project_feedback_conformity_vs_non_conformity"

    }
    default {
	set report_code_found_p 0
    }
}

# ---------------------------------------------------------------------------

# Loading ExtJS libs
im_sencha_extjs_load_libraries
