# /packages/intranet-trans-project-feedback/tcl/intranet-trans-project-feedback-procs.tcl
#
# Copyright (C) 2015 Project Open Business Solutions S.L. 
#
# This program is free software. You can redistribute it
# and/or modify it under the terms of the GNU General
# Public License as published by the Free Software Foundation;
# either version 2 of the License, or (at your option)
# any later version. This program is distributed in the
# hope that it will be useful, but WITHOUT ANY WARRANTY;
# without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.

# Profiles represent OpenACS groups used by ]project-open[
# However, for performance reasons we have introduced special
# caching and auxillary functions specific to ]po[.

# @author klaus.hofeditz@project-open.com


ad_proc -public im_project_translation_feedback_questions_component {
    project_id
    { return_url "" }
} {
    Returns a component showing the feedback questions 
} {

    set params [list \
                    [list project_id $project_id] \
                    [list return_url $return_url] \
               ]

    return [string trim [ad_parse_template -params $params "/packages/intranet-trans-project-feedback/lib/survey-component"]]
}


ad_proc -public im_project_translation_graph_panel {
    title 
    start_date
    end_date
    period
} {
    Creates graphs used on Dashboard
} {

    set params [list \
                    [list title $title] \
                    [list start_date $start_date] \
                    [list end_date $end_date] \
                    [list period $period] \
                    ]

    return [string trim [ad_parse_template -params $params "/packages/intranet-trans-project-feedback/lib/graph-panel"]]
}


proc_doc survsimp_question_display_trans_feedback {
    question_id
    related_object_id
    { edit_previous_response_p "f" }
} "

	Customized version of simple-survey::survsimp_question_display 
	Ignores user - simple shows results of last responce collection 

        Returns a string of HTML to display for a question,
        suitable for embedding in a form.
        The form variable is of the form \"response_to_question.\$question_id
" {
    set element_name "response_to_question.$question_id"

    db_1row survsimp_question_properties "
        select
                survey_id,
                sort_key,
                question_text,
                abstract_data_type,
                required_p,
                active_p,
                presentation_type,
                presentation_options,
                presentation_alignment,
                creation_user,
                creation_date
        from
                survsimp_questions, acs_objects
        where
                object_id = question_id
                and question_id = :question_id
    "

    set html $question_text
    if { $presentation_alignment == "below" } {
        append html "<br>"
    } else {
        append html " "
    }

    set user_value ""

    if {$edit_previous_response_p == "t"} {
        set user_id [ad_get_user_id]

        set prev_response_query "
        select
                choice_id,
                boolean_answer,
                clob_answer,
                number_answer,
                varchar_answer,
                date_answer,
                attachment_file_name
        from
                survsimp_question_responses
        where
                question_id = :question_id
                and response_id = (
                        select  max(response_id)
                        from    survsimp_responses r, survsimp_questions q, acs_objects
                        where   q.question_id = :question_id
                                and object_id = r.survey_id
                                -- and creation_user = :user_id (CUST)
                                and q.survey_id = r.survey_id
				and r.related_object_id = :related_object_id --(CUST)
                )
        "

        set count 0
        db_foreach survsimp_response $prev_response_query {
            incr count
            if {$presentation_type == "checkbox"} {
                set selected_choices($choice_id) "t"
            }
        } if_no_rows {
            set choice_id 0
            set boolean_answer ""
            set clob_answer ""
            set number_answer ""
            set varchar_answer ""
            set date_answer ""
            set attachment_file_name ""
        }
    }

    switch -- $presentation_type {
        "none" {
            append html ""
        }
        "combined_type_one" {
            # get all subquestions
            if {[catch {
                # Ignore question text
                set html [create_html_combined_type_one $question_id]
            } err_msg]} {
                append html "Presentation type not supported, please install package \]po\[ Employee Evaluation"
                ad_return_complaint xx $err_msg
            }
        }
        "upload_file"  {
            if {$edit_previous_response_p == "t"} {
                set user_value $attachment_file_name
            }
            append html "<input type=file name=$element_name $presentation_options>"
        }
        "textbox" {
            if {$edit_previous_response_p == "t"} {
                if {$abstract_data_type == "number" || $abstract_data_type == "integer"} {
                    set user_value $number_answer
                } else {
                    set user_value $varchar_answer
                }
            }

            append html "<input type=text name=$element_name value=\"[philg_quote_double_quotes $user_value]\" [ad_decode $presentation_options "large" "size=70" "medium" "size=40" "size=10"]>"
        }
        "textarea" {
            if {$edit_previous_response_p == "t"} {
                if {$abstract_data_type == "number" || $abstract_data_type == "integer"} {
                    set user_value $number_answer
                } elseif { $abstract_data_type == "shorttext" } {
                    set user_value $varchar_answer
                } else {
                    set user_value $clob_answer
                }
            }

            append html "<textarea name=$element_name $presentation_options>$user_value</textarea>"
        }
        "date" {
            if {$edit_previous_response_p == "t"} {
                set user_value $date_answer
            }

            append html "[ad_dateentrywidget $element_name $user_value]"
        }
        "select" {
            if { $abstract_data_type == "boolean" } {
                if {$edit_previous_response_p == "t"} {
                    set user_value $boolean_answer
                }

                append html "
                <select name=$element_name>
                 <option value=\"\">[lang::message::lookup "" simple-survey.Select_One "Select One"]</option>
                 <option value=\"t\" [ad_decode $user_value "t" "selected" ""]>True</option>
                 <option value=\"f\" [ad_decode $user_value "f" "selected" ""]>False</option>
                </select>
                "
            } else {
                if {$edit_previous_response_p == "t"} {
                    set user_value $choice_id
                }

                append html "
                <select name=$element_name>
                <option value=\"\">[lang::message::lookup "" simple-survey.Select_One "Select One"]</option>
                "
                db_foreach survsimp_question_choices "
                        select choice_id, label
                        from survsimp_question_choices
                        where question_id = :question_id
                        order by sort_order
                " {
                    if { $user_value == $choice_id } {
                        append html "<option value=$choice_id selected>$label</option>\n"
                    } else {
                        append html "<option value=$choice_id>$label</option>\n"
                    }
                }
                append html "</select>"
            }
        }

        "radio" {
            if { $abstract_data_type == "boolean" } {

                if {$edit_previous_response_p == "t"} { set user_value $boolean_answer }
                set choices [list \
				 "<input type=radio name=$element_name value=t [ad_decode $user_value "t" "checked" ""]> True" \
				 "<input type=radio name=$element_name value=f [ad_decode $user_value "f" "checked" ""]> False" \
				 ]

            } else {
                if {$edit_previous_response_p == "t"} { set user_value $choice_id }

                set choices [list]
                db_foreach sursimp_question_choices_2 "
                        select  choice_id, label
                        from    survsimp_question_choices
                        where   question_id = :question_id
                        order by sort_order
                " {
                    if { $user_value == $choice_id } {
                        lappend choices "<input type=radio name=$element_name value=$choice_id checked> $label"
                    } else {
                        lappend choices "<input type=radio name=$element_name value=$choice_id> $label"
                    }
                }
            }
            if { $presentation_alignment == "beside" } {
                append html [join $choices " "]
            } else {
                append html "<blockquote>\n[join $choices "<br>\n"]\n</blockquote>"
            }
        }

        "checkbox" {
            set choices [list]
            db_foreach sursimp_question_choices_3 "
                select * from survsimp_question_choices
                where question_id = :question_id
                order by sort_order
                " {

                    if { [info exists selected_choices($choice_id)] } {
                        lappend choices "<input type=checkbox name=$element_name value=$choice_id checked> $label"
                    } else {
                        lappend choices "<input type=checkbox name=$element_name value=$choice_id> $label"
                    }
                }
            if { $presentation_alignment == "beside" } {
                append html [join $choices " "]
            } else {
                append html "<blockquote>\n[join $choices "<br>\n"]\n</blockquote>"
            }
        }


    }
    return $html
}
